<?php

defined('ABSPATH') or exit();
 /*
 * Plugin Name: iPay88 QR Code for WooCommerce v4.x 
 * Plugin URI: https://docs.ipay88.co.id/woocommerce
 * Description: Allows you to use iPay88 QR Code Payment with the WooCommerce plugin.
 * Version:  1.0.0
 * Author: iPay88 Indonesia
 * Author URI: https://www.ipay88.co.id/
 * Text Domain: hhttps://www.ipay88.co.id/
 * License: The MIT License (MIT)
 *
 */

define('IPAY88_QR_TEXT_DOMAIN', 'ipay88-qr-for-woocommerce');
define('IPAY88_QR_DEFAULT_SUCCESS_PINGBACK_VALUE', 'OK');
define('IPAY88_QR_ORDER_STATUS_PENDING', 'wc-pending');
define('IPAY88_QR_ORDER_STATUS_COMPLETED', 'wc-completed');
define('IPAY88_QR_ORDER_STATUS_PROCESSING', 'wc-processing');
define('IPAY88_QR_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('IPAY88_QR_PLUGIN_URL', plugins_url('', __FILE__));


function load_ipay88_qr_payments() 
{
	if (!class_exists('WC_Payment_Gateway')) return; // Nothing happens here is WooCommerce is not loaded

    include(IPAY88_QR_PLUGIN_PATH . '/lib/ipay88-qr-php/Autoload.php');
    include(IPAY88_QR_PLUGIN_PATH . '/includes/class-ipay88-qr-abstract.php');
    include(IPAY88_QR_PLUGIN_PATH . '/includes/class-ipay88-qr-gateway.php');
    include(IPAY88_QR_PLUGIN_PATH . '/includes/class-ipay88-compat.php');

    function ipay88_qr_payments($methods) 
	{
        $methods[] = 'ipay88_qr_gateway';
        return $methods;
    }

    add_filter('woocommerce_payment_gateways', 'ipay88_qr_payments');
}

add_action('plugins_loaded', 'load_ipay88_qr_payments', 0);

/**
 * Add ipay88_qr Scripts
 */
function ipay88_qr_scripts() 
{
    wp_register_script('placeholder', IPAY88_QR_PLUGIN_URL.'/assets/js/payment.js', array('jquery'), '1', true);
    wp_enqueue_script('placeholder');
}

add_action('wp_enqueue_scripts', 'ipay88_qr_scripts');

/**
 * Require the woocommerce plugin installed first
 */
function ipay88_qr_child_plugin_notice() 
{ ?>
	<div class="error">
    <p><?php echo __("Sorry, but iPay88 QR Code Payment Plugin requires the Woocommerce plugin to be installed and active.", IPAY88_QR_TEXT_DOMAIN)?></p>
    </div>
<?php
}

function ipay88_qr_child_plugin_has_parent_plugin() 
{
	if (is_admin() && current_user_can('activate_plugins') && !is_plugin_active('woocommerce/woocommerce.php')) 
	{
        add_action('admin_notices', 'pw_child_plugin_notice');

        deactivate_plugins(plugin_basename(__FILE__));
        if (isset($_GET['activate'])) 
		{
            unset($_GET['activate']);
        }
    }
}

add_action('admin_init', 'ipay88_qr_child_plugin_has_parent_plugin');

/**
 * Adds plugin page links
 *
 * @since 1.0.0
 * @param array $links all plugin links
 * @return array $links all plugin links + our custom links (i.e., "Settings")
 */
function wc_ipay88_qr_gateway_plugin_links( $links ) 
{
    $plugin_links = array(
        '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=checkout&section=ipay88_qr' ) . '">' . __( 'Setting', 'ipay88_qr' ) . '</a>'
    );
    return array_merge( $plugin_links, $links );
}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wc_ipay88_qr_gateway_plugin_links' );


class WC_iPay88_QR
{
	/**
	 * Savely get POST variables
	 *
	 * @since 1.1
	 * @param string $name POST variable name
	 * @return string The variable value
	 */
	public static function get_post( $name ) {
		if ( isset( $_POST[ $name ] ) ) {
		    return $_POST[ $name ];
		}
		return null;
	}
	
  /**
	 * WC Logger object
	 * @var object
	 */
	private static $log;

	/**
	 * Load gateway files
	 *
	 * @since 1.1
	 */
	public function load_gateway_files() {
		include_once('includes/class-wc-compat-ipay88.php');

	}

	/**
	 * Add debug log message
	 *
	 * @since 1.1
	 * @param string $message
	 */
	public static function add_debug_log( $message ) {
		if ( ! is_object( self::$log ) ) {
			self::$log = WC_Compat_iPay88_QR::get_wc_logger();
		}

		self::$log->add( 'ipay88', $message );
	}

	/**
	 * Savely get GET variables
	 *
	 * @since 1.1
	 * @param string $name GET variable name
	 * @return string The variable value
	 */
    public static function get_get( $name ) {
		if ( isset( $_GET[ $name ] ) ) {
		    return $_GET[ $name ];
		}
		return null;
	}


} new WC_iPay88_QR();